@@ -142,7 +142,7 @@ end
 
 
 function read_element(communicator)
-   typeid = read_bin(communicator, UInt8)
+   typeid = read_byte(communicator)
 
    if typeid == TYPE_ID_LIST
       return read_list(communicator)
@@ -337,7 +337,7 @@ function read_call(communicator, name::AbstractString)
    fails = Vector{Fail}()
    fun = () -> nothing
    try
-      fun = findfield(name)
+      fun::Union{Function, Type} = findfield(name)
    catch ex
       push!(fails, Fail("Unable to identify function", ex))
    end
